@@ -402,17 +402,15 @@ const MHFSCLTrack = async function(gsignal, theURL, DLMGR) {
     if(!that.ptr) throw("failed malloc");
     const rd = MHFSCL.mhfs_cl_track_return_data.from(that.ptr + alignedTrackSize);
     const thatid = MHFSCLObjectMap.addData(that);
-    const pFullFilename = MHFSCL.Module.allocateUTF8(theURL);
+    const pFullFilename = MHFSCL.Module.stringToNewUTF8(theURL);
     let pMime;
     try {
         // initialize the track
         let start = 0;
         const firstreq = await that._downloadChunk(start, gsignal);
         const mime = firstreq.headers['Content-Type'] || '';
-        pMime = MHFSCL.Module.allocateUTF8(mime);
+        pMime = MHFSCL.Module.stringToNewUTF8(mime);
         const totalPCMFrames = BigInt(firstreq.headers['X-MHFS-totalPCMFrameCount'] || 0);
-        const totalPCMFramesLo = Number(totalPCMFrames & BigInt(0xFFFFFFFF));
-        const totalPCMFramesHi = Number((totalPCMFrames >> BigInt(32)) & BigInt(0xFFFFFFFF));
         MHFSCL.Module._mhfs_cl_track_init(that.ptr, that.CHUNKSIZE);
         that.initialized = true;
         that._storeChunk(firstreq, start);
@@ -420,7 +418,7 @@ const MHFSCLTrack = async function(gsignal, theURL, DLMGR) {
         // load enough of the track that the metadata loads
         for(;;) {
             that.picture = null;
-            const code = MHFSCL.Module._mhfs_cl_track_load_metadata(that.ptr, rd.ptr, pMime, pFullFilename, totalPCMFramesLo, totalPCMFramesHi, MHFSCL.pMHFSCLTrackOnMeta, thatid);
+            const code = MHFSCL.Module._mhfs_cl_track_load_metadata(that.ptr, rd.ptr, pMime, pFullFilename, totalPCMFrames, MHFSCL.pMHFSCLTrackOnMeta, thatid);
             if(code === MHFSCL.MHFS_CL_SUCCESS) {
                 break;
             }
@@ -732,6 +730,7 @@ const ExposeType_LoadTypes = function(BINDTO, wasmMod, loadType) {
 
 Module().then(function(MHFSCLMod){
     MHFSCL.Module = MHFSCLMod;
+    MHFSCL.Module.stringToNewUTF8 ||= MHFSCL.Module.allocateUTF8; // < 3.1.35 emcc compat
 
     // Load types
     ExposeType_LoadTypes(MHFSCL, MHFSCL.Module, MHFSCL.Module._mhfs_cl_et_load_type);
